@@ -4,7 +4,7 @@
 ///         sieving. It is used for printing and counting primes
 ///         and for computing the nth prime.
 ///
-/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2024 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -13,14 +13,12 @@
 #ifndef PRIMESIEVE_CLASS_HPP
 #define PRIMESIEVE_CLASS_HPP
 
-#include "PreSieve.hpp"
-#include "pod_vector.hpp"
-
+#include "Vector.hpp"
 #include <stdint.h>
 
 namespace primesieve {
 
-using counts_t = pod_array<uint64_t, 6>;
+using counts_t = Array<uint64_t, 6>;
 class ParallelSieve;
 
 enum
@@ -52,7 +50,6 @@ public:
   uint64_t getDistance() const;
   int getSieveSize() const;
   double getSeconds() const;
-  PreSieve& getPreSieve();
   // Setters
   void setStart(uint64_t);
   void setStop(uint64_t);
@@ -78,6 +75,7 @@ public:
   // nth prime
   uint64_t nthPrime(uint64_t);
   uint64_t nthPrime(int64_t, uint64_t);
+  uint64_t negativeNthPrime(int64_t, uint64_t);
   // Count
   counts_t& getCounts();
   uint64_t getCount(int) const;
@@ -106,7 +104,6 @@ private:
   int sieveSize_ = 0;
   /// Status updates must be synchronized by main thread
   ParallelSieve* parent_ = nullptr;
-  PreSieve preSieve_;
   void processSmallPrimes();
   static void printStatus(double, double);
 };
