@@ -1,16 +1,16 @@
 ///
-/// @file  MemoryPool.cpp
-///        EratMedium and EratBig may use millions of buckets for
-///        storing the sieving primes that are required to cross off
-///        multiples. As many memory allocations/deallocations are
-///        bad for performance the MemoryPool initially allocates a
-///        large number of buckets (using a single memory allocation)
-///        and puts the buckets into its stock. The MemoryPool can
-///        then serve buckets to EratMedium and EratBig without
-///        doing any memory allocation as long as the MemoryPool's
-///        stock is not empty.
+/// @file   MemoryPool.cpp
+/// @brief  EratMedium and EratBig may use millions of buckets for
+///         storing the sieving primes that are required to cross off
+///         multiples. As many memory allocations/deallocations are
+///         bad for performance the MemoryPool initially allocates a
+///         large number of buckets (using a single memory allocation)
+///         and puts the buckets into its stock. The MemoryPool can
+///         then serve buckets to EratMedium and EratBig without
+///         doing any memory allocation as long as the MemoryPool's
+///         stock is not empty.
 ///
-/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2023 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -20,7 +20,7 @@
 #include <primesieve/config.hpp>
 #include <primesieve/Bucket.hpp>
 #include <primesieve/macros.hpp>
-#include <primesieve/pod_vector.hpp>
+#include <primesieve/Vector.hpp>
 #include <primesieve/primesieve_error.hpp>
 
 #include <algorithm>
