@@ -11,7 +11,7 @@
 ///         fillNextPrimes() is highly optimized using hardware
 ///         acceleration (e.g. CTZ, AVX512) whenever possible.
 ///
-/// Copyright (C) 2023 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2024 Kim Walisch, <kim.walisch@gmail.com>
 /// Copyright (C) 2022 @zielaj, https://github.com/zielaj
 ///
 /// This file is distributed under the BSD License. See the COPYING
@@ -22,20 +22,20 @@
 #include <primesieve/forward.hpp>
 #include <primesieve/littleendian_cast.hpp>
 #include <primesieve/macros.hpp>
-#include <primesieve/PreSieve.hpp>
 #include <primesieve/PrimeGenerator.hpp>
 #include <primesieve/primesieve_error.hpp>
 #include <primesieve/macros.hpp>
 #include <primesieve/pmath.hpp>
+#include <primesieve/popcnt.hpp>
 #include <primesieve/Vector.hpp>
-#include <primesieve/intrinsics.hpp>
 #include <primesieve/SievingPrimes.hpp>
 
 #include <stdint.h>
 #include <algorithm>
 #include <limits>
 
-#if defined(MULTIARCH_AVX512)
+#if defined(ENABLE_AVX512_VBMI2) || \
+    defined(ENABLE_MULTIARCH_AVX512_VBMI2)
   #include <immintrin.h>
 #endif
 
@@ -117,10 +117,8 @@ const primesieve::Array<uint8_t, 720> primePi =
 namespace primesieve {
 
 PrimeGenerator::PrimeGenerator(uint64_t start,
-                               uint64_t stop,
-                               PreSieve& preSieve) :
-  Erat(start, stop),
-  preSieve_(preSieve)
+                               uint64_t stop) :
+  Erat(start, stop)
 { }
 
 uint64_t PrimeGenerator::maxCachedPrime()
@@ -271,10 +269,9 @@ void PrimeGenerator::initErat()
   if (startErat <= stop_ &&
       startErat < std::numeric_limits<uint64_t>::max())
   {
-    preSieve_.init(startErat, stop_);
     int sieveSize = get_sieve_size();
-    Erat::init(startErat, stop_, sieveSize, preSieve_, memoryPool_);
-    sievingPrimes_.init(this, sieveSize, preSieve_, memoryPool_);
+    Erat::init(startErat, stop_, sieveSize, memoryPool_);
+    sievingPrimes_.init(this, sieveSize, memoryPool_);
   }
 }
 
@@ -393,6 +390,8 @@ void PrimeGenerator::fillPrevPrimes(Vector<uint64_t>& primes,
   }
 }
 
+#if defined(ENABLE_DEFAULT)
+
 /// This method is used by iterator::next_prime().
 /// This method stores only the next few primes (~ 1000) in the
 /// primes vector. Also for iterator::next_prime() there is no
@@ -400,72 +399,7 @@ void PrimeGenerator::fillPrevPrimes(Vector<uint64_t>& primes,
 /// this reason iterator::next_prime() runs up to 2x faster
 /// than iterator::prev_prime().
 ///
-#if defined(MULTIARCH)
-  __attribute__ ((target ("default")))
-#endif
-void PrimeGenerator::fillNextPrimes(Vector<uint64_t>& primes,
-                                    std::size_t* size)
-{
-  *size = 0;
-
-  do
-  {
-    if (sieveIdx_ >= sieve_.size())
-      if (!sieveNextPrimes(primes, size))
-        return;
-
-    // Use local variables to prevent the compiler from
-    // writing temporary results to memory.
-    std::size_t i = *size;
-    std::size_t maxSize = primes.size();
-    ASSERT(i + 64 <= maxSize);
-    uint64_t low = low_;
-    uint64_t sieveIdx = sieveIdx_;
-    uint64_t sieveSize = sieve_.size();
-    uint8_t* sieve = sieve_.data();
-
-    // Fill the buffer with at least (maxSize - 64) primes.
-    // Each loop iteration can generate up to 64 primes
-    // so we have to stop generating primes once there is
-    // not enough space for 64 more primes.
-    do
-    {
-      uint64_t bits = littleendian_cast<uint64_t>(&sieve[sieveIdx]);
-      std::size_t j = i;
-      i += popcnt64(bits);
-
-      do
-      {
-        primes[j+0] = nextPrime(bits, low); bits &= bits - 1;
-        primes[j+1] = nextPrime(bits, low); bits &= bits - 1;
-        primes[j+2] = nextPrime(bits, low); bits &= bits - 1;
-        primes[j+3] = nextPrime(bits, low); bits &= bits - 1;
-        j += 4;
-      }
-      while (j < i);
-
-      low += 8 * 30;
-      sieveIdx += 8;
-    }
-    while (i <= maxSize - 64 &&
-           sieveIdx < sieveSize);
-
-    low_ = low;
-    sieveIdx_ = sieveIdx;
-    *size = i;
-  }
-  while (*size == 0);
-}
-
-#if defined(MULTIARCH_POPCNT_BMI)
-
-/// This algorithm is identical to the default fillNextPrimes()
-/// method, except that the POPCNT & BMI instruction sets (x64 CPUs)
-/// have been enabled which should provide up to 10% speedup.
-///
-__attribute__ ((target ("popcnt,bmi")))
-void PrimeGenerator::fillNextPrimes(Vector<uint64_t>& primes,
-                                    std::size_t* size)
+void PrimeGenerator::fillNextPrimes_default(Vector<uint64_t>& primes, std::size_t* size)
 {
   *size = 0;
 
@@ -520,7 +454,8 @@ void PrimeGenerator::fillNextPrimes(Vector<uint64_t>& primes,
 
 #endif
 
-#if defined(MULTIARCH_AVX512)
+#if defined(ENABLE_AVX512_VBMI2) || \
+    defined(ENABLE_MULTIARCH_AVX512_VBMI2)
 
 /// This algorithm converts 1 bits from the sieve array into primes
 /// using AVX512. The algorithm is a modified version of the AVX512
@@ -535,9 +470,10 @@ void PrimeGenerator::fillNextPrimes(Vector<uint64_t>& primes,
 /// benchmarks this algorithm ran about 10% faster than the default
 /// fillNextPrimes() algorithm which uses __builtin_ctzll().
 ///
-__attribute__ ((target ("avx512f,avx512vbmi,avx512vbmi2,popcnt")))
-void PrimeGenerator::fillNextPrimes(Vector<uint64_t>& primes,
-                                    std::size_t* size)
+#if defined(ENABLE_MULTIARCH_AVX512_VBMI2)
+  __attribute__ ((target ("avx512f,avx512vbmi,avx512vbmi2")))
+#endif
+void PrimeGenerator::fillNextPrimes_avx512(Vector<uint64_t>& primes, std::size_t* size)
 {
   *size = 0;
 
